@@ -4,7 +4,6 @@ ME=`whoami`
 echo "Running as user: $ME"
 MVN=$1
 VERSION=$2
-BRANCH=$3
 
 check_user() {
     ME=$1
@@ -23,7 +22,7 @@ fi
 
 # This should only be done on the stack forge system
 if [ "${BUILD_COMMON}" = "true" ]; then
-   git clone -b ${BRANCH} https://git.openstack.org/openstack/monasca-common
+   git clone https://github.com/stackforge/monasca-common
    cd monasca-common
    ${MVN} clean
    ${MVN} install
