@@ -1,18 +1,19 @@
 /*
  * Copyright (c) 2014 Hewlett-Packard Development Company, L.P.
  *
- * Copyright (c) 2017 SUSE LLC.
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
- * implied.
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
@@ -21,7 +22,6 @@ package monasca.persister.configuration;
 
 import com.fasterxml.jackson.annotation.JsonProperty;
 
-import monasca.common.configuration.CassandraDbConfiguration;
 import monasca.common.configuration.DatabaseConfiguration;
 import monasca.common.configuration.InfluxDbConfiguration;
 import io.dropwizard.Configuration;
@@ -100,12 +100,4 @@ public class PersisterConfig extends Configuration {
   public InfluxDbConfiguration getInfluxDBConfiguration() {
     return influxDbConfiguration;
   }
-
-  @Valid
-  @JsonProperty
-  private final CassandraDbConfiguration cassandraDbConfiguration = new CassandraDbConfiguration();
-
-  public CassandraDbConfiguration getCassandraDbConfiguration() {
-    return cassandraDbConfiguration;
-  }
 }
