@@ -24,11 +24,15 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import java.util.concurrent.ExecutorService;
+import java.util.concurrent.Executors;
+import java.util.concurrent.TimeUnit;
 
 public class KafkaConsumer<T> {
 
   private static final Logger logger = LoggerFactory.getLogger(KafkaConsumer.class);
 
+  private static final int WAIT_TIME = 10;
+
   private ExecutorService executorService;
 
   private final KafkaConsumerRunnableBasic<T> kafkaConsumerRunnableBasic;
@@ -37,12 +41,10 @@ public class KafkaConsumer<T> {
   @Inject
   public KafkaConsumer(
       @Assisted KafkaConsumerRunnableBasic<T> kafkaConsumerRunnableBasic,
-      @Assisted String threadId,
-      @Assisted ExecutorService executorService) {
+      @Assisted String threadId) {
 
     this.kafkaConsumerRunnableBasic = kafkaConsumerRunnableBasic;
     this.threadId = threadId;
-    this.executorService = executorService;
 
   }
 
@@ -50,7 +52,9 @@ public class KafkaConsumer<T> {
 
     logger.info("[{}]: start", this.threadId);
 
-    executorService.submit(kafkaConsumerRunnableBasic.setExecutorService(executorService));
+    executorService = Executors.newFixedThreadPool(1);
+
+    executorService.submit(kafkaConsumerRunnableBasic);
 
   }
 
@@ -60,5 +64,29 @@ public class KafkaConsumer<T> {
 
     kafkaConsumerRunnableBasic.stop();
 
+    if (executorService != null) {
+
+      logger.info("[{}]: shutting down executor service", this.threadId);
+
+      executorService.shutdown();
+
+      try {
+
+        logger.info("[{}]: awaiting termination...", this.threadId);
+
+        if (!executorService.awaitTermination(WAIT_TIME, TimeUnit.SECONDS)) {
+
+          logger.warn("[{}]: did not shut down in {} seconds", this.threadId, WAIT_TIME);
+
+        }
+
+        logger.info("[{}]: terminated", this.threadId);
+
+      } catch (InterruptedException e) {
+
+        logger.info("[{}]: awaitTermination interrupted", this.threadId, e);
+
+      }
+    }
   }
 }
