@@ -1,8 +1,6 @@
 /*
  * Copyright (c) 2014 Hewlett-Packard Development Company, L.P.
- * 
- * Copyright (c) 2017 SUSE LLC
- * 
+ *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
@@ -19,10 +17,6 @@
 
 package monasca.persister.pipeline.event;
 
-import monasca.common.model.metric.MetricEnvelope;
-import monasca.persister.configuration.PipelineConfig;
-import monasca.persister.repository.Repo;
-
 import com.google.inject.Inject;
 import com.google.inject.assistedinject.Assisted;
 
@@ -33,48 +27,43 @@ import com.fasterxml.jackson.databind.PropertyNamingStrategy;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.io.IOException;
-
 import io.dropwizard.setup.Environment;
-import monasca.persister.repository.RepoException;
+import monasca.common.model.metric.MetricEnvelope;
+import monasca.persister.configuration.PipelineConfig;
+import monasca.persister.repository.Repo;
 
 public class MetricHandler extends FlushableHandler<MetricEnvelope[]> {
 
-  private static final Logger logger = LoggerFactory.getLogger(MetricHandler.class);
+  private static final Logger logger =
+      LoggerFactory.getLogger(MetricHandler.class);
 
   private final Repo<MetricEnvelope> metricRepo;
 
   private final Counter metricCounter;
 
   @Inject
-  public MetricHandler(Repo<MetricEnvelope> metricRepo, Environment environment,
-      @Assisted PipelineConfig configuration, @Assisted("threadId") String threadId,
+  public MetricHandler(
+      Repo<MetricEnvelope> metricRepo,
+      Environment environment,
+      @Assisted PipelineConfig configuration,
+      @Assisted("threadId") String threadId,
       @Assisted("batchSize") int batchSize) {
 
     super(configuration, environment, threadId, batchSize);
 
     this.metricRepo = metricRepo;
 
-    this.metricCounter = environment.metrics()
-        .counter(this.handlerName + "." + "metrics-added-to-batch-counter");
+    this.metricCounter =
+        environment.metrics()
+            .counter(this.handlerName + "." + "metrics-added-to-batch-counter");
 
   }
 
   @Override
-  public int process(String msg) {
+  public int process(String msg) throws Exception {
 
-    MetricEnvelope[] metricEnvelopesArry;
-
-    try {
-
-      metricEnvelopesArry = this.objectMapper.readValue(msg, MetricEnvelope[].class);
-
-    } catch (IOException e) {
-
-      logger.error("[{}]: failed to deserialize message {}", this.threadId, msg, e);
-
-      return 0;
-    }
+    MetricEnvelope[] metricEnvelopesArry =
+        objectMapper.readValue(msg, MetricEnvelope[].class);
 
     for (final MetricEnvelope metricEnvelope : metricEnvelopesArry) {
 
@@ -86,12 +75,14 @@ public class MetricHandler extends FlushableHandler<MetricEnvelope[]> {
   }
 
   private void processEnvelope(MetricEnvelope metricEnvelope) {
-    if (logger.isDebugEnabled()) {
-      logger.debug("[{}]: [{}:{}] {}", this.threadId, this.getBatchCount(), this.getMsgCount(),
-          metricEnvelope);
-    }
 
-    this.metricRepo.addToBatch(metricEnvelope, this.threadId);
+    logger.debug("[{}]: [{}:{}] {}",
+                 this.threadId,
+                 this.getBatchCount(),
+                 this.getMsgCount(),
+                 metricEnvelope);
+
+    this.metricRepo.addToBatch(metricEnvelope);
 
     this.metricCounter.inc();
 
@@ -104,15 +95,15 @@ public class MetricHandler extends FlushableHandler<MetricEnvelope[]> {
 
     this.objectMapper.enable(DeserializationFeature.ACCEPT_SINGLE_VALUE_AS_ARRAY);
 
-    this.objectMapper
-        .setPropertyNamingStrategy(PropertyNamingStrategy.CAMEL_CASE_TO_LOWER_CASE_WITH_UNDERSCORES);
+    this.objectMapper.setPropertyNamingStrategy(
+        PropertyNamingStrategy.CAMEL_CASE_TO_LOWER_CASE_WITH_UNDERSCORES);
 
   }
 
   @Override
-  public int flushRepository() throws RepoException {
+  public int flushRepository() throws Exception {
 
-    return this.metricRepo.flush(this.threadId);
+    return metricRepo.flush(this.threadId);
   }
 
 }
