@@ -26,7 +26,6 @@ import java.util.List;
 import java.util.Map;
 
 import io.dropwizard.setup.Environment;
-import monasca.persister.repository.RepoException;
 
 public class InfluxV9MetricRepo extends InfluxMetricRepo {
 
@@ -44,13 +43,13 @@ public class InfluxV9MetricRepo extends InfluxMetricRepo {
   }
 
   @Override
-  protected int write(String id) throws RepoException {
+  protected int write(String id) throws Exception {
 
     return this.influxV9RepoWriter.write(getInfluxPointArry(), id);
 
   }
 
-  private InfluxPoint[] getInfluxPointArry() {
+  private InfluxPoint[] getInfluxPointArry() throws Exception {
 
     List<InfluxPoint> influxPointList = new LinkedList<>();
 
@@ -95,11 +94,7 @@ public class InfluxV9MetricRepo extends InfluxMetricRepo {
 
     String valueMetaJSONString = measurement.getValueMetaJSONString();
 
-    if (valueMetaJSONString == null || valueMetaJSONString.isEmpty()) {
-
-      valueMap.put("value_meta", "{}");
-
-    } else {
+    if (valueMetaJSONString != null) {
 
       valueMap.put("value_meta", valueMetaJSONString);
 
