@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 2014-2016 Hewlett Packard Enterprise Development LP
+ * Copyright (c) 2014 Hewlett-Packard Development Company, L.P.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,14 +17,17 @@
 
 package monasca.persister.repository.vertica;
 
-import com.google.common.base.Stopwatch;
+import monasca.common.model.metric.Metric;
+import monasca.common.model.metric.MetricEnvelope;
+import monasca.persister.configuration.PersisterConfig;
+import monasca.persister.pipeline.event.MetricHandler;
+
 import com.google.common.cache.Cache;
 import com.google.common.cache.CacheBuilder;
 
+import com.codahale.metrics.Counter;
 import com.codahale.metrics.Meter;
 import com.codahale.metrics.Timer;
-import com.fasterxml.jackson.core.JsonProcessingException;
-import com.fasterxml.jackson.databind.ObjectMapper;
 
 import org.apache.commons.codec.digest.DigestUtils;
 import org.skife.jdbi.v2.DBI;
@@ -38,6 +41,7 @@ import java.text.SimpleDateFormat;
 import java.util.Date;
 import java.util.HashSet;
 import java.util.Map;
+import java.util.Random;
 import java.util.Set;
 import java.util.TimeZone;
 import java.util.TreeMap;
@@ -45,11 +49,7 @@ import java.util.TreeMap;
 import javax.inject.Inject;
 
 import io.dropwizard.setup.Environment;
-import monasca.common.model.metric.Metric;
-import monasca.common.model.metric.MetricEnvelope;
-import monasca.persister.configuration.PersisterConfig;
 import monasca.persister.repository.Repo;
-import monasca.persister.repository.RepoException;
 
 public class VerticaMetricRepo extends VerticaRepo implements Repo<MetricEnvelope> {
 
@@ -57,8 +57,6 @@ public class VerticaMetricRepo extends VerticaRepo implements Repo<MetricEnvelop
 
   public static final int MAX_COLUMN_LENGTH = 255;
 
-  public static final int MAX_VALUE_META_LENGTH = 2048;
-
   private final SimpleDateFormat simpleDateFormat;
 
   private static final String TENANT_ID = "tenantId";
@@ -74,13 +72,8 @@ public class VerticaMetricRepo extends VerticaRepo implements Repo<MetricEnvelop
   private final Set<Sha1HashId> dimensionIdSet = new HashSet<>();
   private final Set<Sha1HashId> definitionDimensionsIdSet = new HashSet<>();
 
-  private int measurementCnt = 0;
-
-  private final ObjectMapper objectMapper = new ObjectMapper();
-
   private static final String SQL_INSERT_INTO_METRICS =
-      "insert into MonMetrics.measurements (definition_dimensions_id, time_stamp, value, value_meta) "
-      + "values (:definition_dimension_id, :time_stamp, :value, :value_meta)";
+      "insert into MonMetrics.measurements (definition_dimensions_id, time_stamp, value) values (:definition_dimension_id, :time_stamp, :value)";
 
   private static final String DEFINITIONS_TEMP_STAGING_TABLE = "(" + "   id BINARY(20) NOT NULL,"
       + "   name VARCHAR(255) NOT NULL," + "   tenant_id VARCHAR(255) NOT NULL,"
@@ -107,8 +100,13 @@ public class VerticaMetricRepo extends VerticaRepo implements Repo<MetricEnvelop
   private final String dimensionsTempStagingTableInsertStmt;
   private final String definitionDimensionsTempStagingTableInsertStmt;
 
-  private final Timer commitTimer;
 
+  private final Counter metricCounter;
+  private final Counter definitionCounter;
+  private final Counter dimensionCounter;
+  private final Counter definitionDimensionsCounter;
+
+  private final Timer flushTimer;
   public final Meter measurementMeter;
   public final Meter definitionCacheMissMeter;
   public final Meter dimensionCacheMissMeter;
@@ -118,61 +116,60 @@ public class VerticaMetricRepo extends VerticaRepo implements Repo<MetricEnvelop
   public final Meter definitionDimensionCacheHitMeter;
 
   @Inject
-  public VerticaMetricRepo(
-      DBI dbi,
-      PersisterConfig configuration,
-      Environment environment) throws NoSuchAlgorithmException, SQLException {
-
+  public VerticaMetricRepo(DBI dbi, PersisterConfig configuration,
+                           Environment environment) throws NoSuchAlgorithmException, SQLException {
     super(dbi);
-
-    logger.debug("Instantiating " + this.getClass().getName());
+    logger.debug("Instantiating: " + this.getClass().getName());
 
     simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss.SSS");
     simpleDateFormat.setTimeZone(TimeZone.getTimeZone("GMT-0"));
 
     this.environment = environment;
+    final String handlerName = String.format("%s[%d]", MetricHandler.class.getName(), new Random().nextInt());
 
-    this.commitTimer =
-        this.environment.metrics().timer(this.getClass().getName() + "." + "commit-timer");
+    this.metricCounter =
+        environment.metrics().counter(handlerName + "." + "metrics-added-to-batch-counter");
+    this.definitionCounter =
+        environment.metrics()
+            .counter(handlerName + "." + "metric-definitions-added-to-batch-counter");
+    this.dimensionCounter =
+        environment.metrics()
+            .counter(handlerName + "." + "metric-dimensions-added-to-batch-counter");
+    this.definitionDimensionsCounter =
+        environment.metrics()
+            .counter(handlerName + "." + "metric-definition-dimensions-added-to-batch-counter");
 
+    this.flushTimer =
+        this.environment.metrics().timer(this.getClass().getName() + "." + "flush-timer");
     this.measurementMeter =
-        this.environment.metrics()
-            .meter(this.getClass().getName() + "." + "measurement-meter");
-
+        this.environment.metrics().meter(this.getClass().getName() + "." + "measurement-meter");
     this.definitionCacheMissMeter =
-        this.environment.metrics()
-            .meter(this.getClass().getName() + "." + "definition-cache-miss-meter");
-
+        this.environment.metrics().meter(
+            this.getClass().getName() + "." + "definition-cache-miss-meter");
     this.dimensionCacheMissMeter =
-        this.environment.metrics()
-            .meter(this.getClass().getName() + "." + "dimension-cache-miss-meter");
-
+        this.environment.metrics().meter(
+            this.getClass().getName() + "." + "dimension-cache-miss-meter");
     this.definitionDimensionCacheMissMeter =
-        this.environment.metrics()
-            .meter(this.getClass().getName() + "." + "definition-dimension-cache-miss-meter");
-
+        this.environment.metrics().meter(
+            this.getClass().getName() + "." + "definition-dimension-cache-miss-meter");
     this.definitionCacheHitMeter =
-        this.environment.metrics()
-            .meter(this.getClass().getName() + "." + "definition-cache-hit-meter");
-
+        this.environment.metrics().meter(
+            this.getClass().getName() + "." + "definition-cache-hit-meter");
     this.dimensionCacheHitMeter =
-        this.environment.metrics()
-            .meter(this.getClass().getName() + "." + "dimension-cache-hit-meter");
-
+        this.environment.metrics().meter(
+            this.getClass().getName() + "." + "dimension-cache-hit-meter");
     this.definitionDimensionCacheHitMeter =
-        this.environment.metrics()
-            .meter(this.getClass().getName() + "." + "definition-dimension-cache-hit-meter");
+        this.environment.metrics().meter(
+            this.getClass().getName() + "." + "definition-dimension-cache-hit-meter");
 
     definitionsIdCache =
         CacheBuilder.newBuilder()
             .maximumSize(configuration.getVerticaMetricRepoConfig().getMaxCacheSize())
             .build();
-
     dimensionsIdCache =
         CacheBuilder.newBuilder()
             .maximumSize(configuration.getVerticaMetricRepoConfig().getMaxCacheSize())
             .build();
-
     definitionDimensionsIdCache =
         CacheBuilder.newBuilder()
             .maximumSize(configuration.getVerticaMetricRepoConfig().getMaxCacheSize())
@@ -192,29 +189,21 @@ public class VerticaMetricRepo extends VerticaRepo implements Repo<MetricEnvelop
         + definitionDimensionsTempStagingTableName);
 
     this.definitionsTempStagingTableInsertStmt =
-        "merge into MonMetrics.Definitions tgt"
-        + " using " + this.definitionsTempStagingTableName + " src"
-        + " on src.id = tgt.id"
-        + " when not matched then insert values(src.id, src.name, src.tenant_id, src.region)";
-
+        "insert into  MonMetrics.Definitions select distinct * from "
+            + definitionsTempStagingTableName
+            + " where id not in (select id from MonMetrics.Definitions)";
     logger.debug("definitions insert stmt: " + definitionsTempStagingTableInsertStmt);
 
     this.dimensionsTempStagingTableInsertStmt =
-        "merge into MonMetrics.Dimensions tgt "
-        + " using " + this.dimensionsTempStagingTableName + " src"
-        + " on src.dimension_set_id = tgt.dimension_set_id"
-        + " and src.name = tgt.name"
-        + " and src.value = tgt.value"
-        + " when not matched then insert values(src.dimension_set_id, src.name, src.value)";
-
+        "insert into MonMetrics.Dimensions select distinct * from "
+            + dimensionsTempStagingTableName
+            + " where dimension_set_id not in (select dimension_set_id from MonMetrics.Dimensions)";
     logger.debug("dimensions insert stmt: " + definitionsTempStagingTableInsertStmt);
 
     this.definitionDimensionsTempStagingTableInsertStmt =
-        "merge into MonMetrics.definitionDimensions tgt"
-        + " using " + this.definitionDimensionsTempStagingTableName + " src"
-        + " on src.id = tgt.id"
-        + " when not matched then insert values(src.id, src.definition_id, src.dimension_set_id)";
-
+        "insert into MonMetrics.definitionDimensions select distinct * from "
+            + definitionDimensionsTempStagingTableName
+            + " where id not in (select id from MonMetrics.definitionDimensions)";
     logger.debug("definitionDimensions insert stmt: "
         + definitionDimensionsTempStagingTableInsertStmt);
 
@@ -250,144 +239,97 @@ public class VerticaMetricRepo extends VerticaRepo implements Repo<MetricEnvelop
 
     logger.debug("completed database preparations");
 
-    logger.debug(this.getClass().getName() + " is fully instantiated");
+    logger.debug(this.getClass().getName() + "is fully instantiated");
   }
 
   @Override
-  public void addToBatch(MetricEnvelope metricEnvelope, String id) {
+  public void addToBatch(MetricEnvelope metricEnvelope) {
 
     Metric metric = metricEnvelope.metric;
-    Map<String, Object> metaMap = metricEnvelope.meta;
+    Map<String, Object> meta = metricEnvelope.meta;
 
-    String tenantId = getMeta(TENANT_ID, metric, metaMap, id);
+    logger.debug("metric: {}", metric);
+    logger.debug("meta: {}", meta);
 
-    String region = getMeta(REGION, metric, metaMap, id);
+    String tenantId = "";
+    if (meta.containsKey(TENANT_ID)) {
+      tenantId = (String) meta.get(TENANT_ID);
+    } else {
+      logger.warn(
+          "Failed to find tenantId in message envelope meta data. Metric message may be malformed"
+          + ". Setting tenantId to empty string.");
+      logger.warn("metric: {}", metric.toString());
+      logger.warn("meta: {}", meta.toString());
+    }
+
+    String region = "";
+    if (meta.containsKey(REGION)) {
+      region = (String) meta.get(REGION);
+    } else {
+      logger.warn(
+          "Failed to find region in message envelope meta data. Metric message may be malformed. "
+          + "Setting region to empty string.");
+      logger.warn("metric: {}", metric.toString());
+      logger.warn("meta: {}", meta.toString());
+    }
 
     // Add the definition to the batch.
-    StringBuilder definitionIdStringToHash =
-        new StringBuilder(trunc(metric.getName(), MAX_COLUMN_LENGTH, id));
-
-    definitionIdStringToHash.append(trunc(tenantId, MAX_COLUMN_LENGTH, id));
-
-    definitionIdStringToHash.append(trunc(region, MAX_COLUMN_LENGTH, id));
-
+    StringBuilder
+        definitionIdStringToHash =
+        new StringBuilder(trunc(metric.getName(), MAX_COLUMN_LENGTH));
+    definitionIdStringToHash.append(trunc(tenantId, MAX_COLUMN_LENGTH));
+    definitionIdStringToHash.append(trunc(region, MAX_COLUMN_LENGTH));
     byte[] definitionIdSha1Hash = DigestUtils.sha(definitionIdStringToHash.toString());
-
     Sha1HashId definitionSha1HashId = new Sha1HashId((definitionIdSha1Hash));
-
-    addDefinitionToBatch(definitionSha1HashId, trunc(metric.getName(), MAX_COLUMN_LENGTH, id),
-                         trunc(tenantId, MAX_COLUMN_LENGTH, id),
-                         trunc(region, MAX_COLUMN_LENGTH, id), id);
+    this.addDefinitionToBatch(definitionSha1HashId, trunc(metric.getName(), MAX_COLUMN_LENGTH),
+                              trunc(tenantId, MAX_COLUMN_LENGTH), trunc(region, MAX_COLUMN_LENGTH));
+    definitionCounter.inc();
 
     // Calculate dimensions sha1 hash id.
     StringBuilder dimensionIdStringToHash = new StringBuilder();
-
-    Map<String, String> preppedDimMap = prepDimensions(metric.getDimensions(), id);
-
+    Map<String, String> preppedDimMap = prepDimensions(metric.getDimensions());
     for (Map.Entry<String, String> entry : preppedDimMap.entrySet()) {
-
       dimensionIdStringToHash.append(entry.getKey());
-
       dimensionIdStringToHash.append(entry.getValue());
     }
-
     byte[] dimensionIdSha1Hash = DigestUtils.sha(dimensionIdStringToHash.toString());
-
     Sha1HashId dimensionsSha1HashId = new Sha1HashId(dimensionIdSha1Hash);
 
     // Add the dimension name/values to the batch.
-    addDimensionsToBatch(dimensionsSha1HashId, preppedDimMap, id);
+    this.addDimensionsToBatch(dimensionsSha1HashId, preppedDimMap);
 
     // Add the definition dimensions to the batch.
-    StringBuilder definitionDimensionsIdStringToHash =
+    StringBuilder
+        definitionDimensionsIdStringToHash =
         new StringBuilder(definitionSha1HashId.toHexString());
-
     definitionDimensionsIdStringToHash.append(dimensionsSha1HashId.toHexString());
-
-    byte[] definitionDimensionsIdSha1Hash =
+    byte[]
+        definitionDimensionsIdSha1Hash =
         DigestUtils.sha(definitionDimensionsIdStringToHash.toString());
-
     Sha1HashId definitionDimensionsSha1HashId = new Sha1HashId(definitionDimensionsIdSha1Hash);
-
-    addDefinitionDimensionToBatch(definitionDimensionsSha1HashId, definitionSha1HashId,
-                                  dimensionsSha1HashId, id);
+    this.addDefinitionDimensionToBatch(definitionDimensionsSha1HashId, definitionSha1HashId,
+                                       dimensionsSha1HashId);
+    definitionDimensionsCounter.inc();
 
     // Add the measurement to the batch.
     String timeStamp = simpleDateFormat.format(new Date(metric.getTimestamp()));
-
     double value = metric.getValue();
+    this.addMetricToBatch(definitionDimensionsSha1HashId, timeStamp, value, metric.getValueMeta());
 
-    addMetricToBatch(definitionDimensionsSha1HashId, timeStamp, value, metric.getValueMeta(), id);
-
-  }
-
-  private String getMeta(String name, Metric metric, Map<String, Object> meta, String id) {
-
-    if (meta.containsKey(name)) {
-
-      return (String) meta.get(name);
-
-    } else {
-
-      logger.warn(
-          "[{}]: failed to find {} in message envelope meta data. metric message may be malformed. "
-          + "setting {} to empty string.", id, name);
-
-      logger.warn("[{}]: metric: {}", id, metric.toString());
-
-      logger.warn("[{}]: meta: {}", id, meta.toString());
-
-      return "";
-    }
+    this.metricCounter.inc();
   }
 
   public void addMetricToBatch(Sha1HashId defDimsId, String timeStamp, double value,
-                               Map<String, String> valueMeta, String id) {
-
-    String valueMetaString = getValueMetaString(valueMeta, id);
-
-    logger.debug("[{}]: adding metric to batch: defDimsId: {}, time: {}, value: {}, value meta {}",
-                 id, defDimsId.toHexString(), timeStamp, value, valueMetaString);
-
-    metricsBatch.add()
-        .bind("definition_dimension_id", defDimsId.getSha1Hash())
-        .bind("time_stamp", timeStamp)
-        .bind("value", value)
-        .bind("value_meta", valueMetaString);
-
-    this.measurementCnt++;
-
+                               Map<String, String> valueMeta) {
+    // TODO: Actually handle valueMeta
+    logger.debug("Adding metric to batch: defDimsId: {}, time: {}, value: {}",
+                 defDimsId.toHexString(), timeStamp, value);
+    metricsBatch.add().bind("definition_dimension_id", defDimsId.getSha1Hash())
+        .bind("time_stamp", timeStamp).bind("value", value);
     measurementMeter.mark();
   }
 
-  private String getValueMetaString(Map<String, String> valueMeta, String id) {
-
-    String valueMetaString = "";
-
-    if (valueMeta != null && !valueMeta.isEmpty()) {
-
-      try {
-
-        valueMetaString = this.objectMapper.writeValueAsString(valueMeta);
-        if (valueMetaString.length() > MAX_VALUE_META_LENGTH) {
-          logger
-              .error("[{}]: Value meta length {} longer than maximum {}, dropping value meta",
-                     id, valueMetaString.length(), MAX_VALUE_META_LENGTH);
-          return "";
-        }
-
-      } catch (JsonProcessingException e) {
-
-        logger
-            .error("[{}]: Failed to serialize value meta {}, dropping value meta from measurement",
-                   id, valueMeta);
-      }
-    }
-
-    return valueMetaString;
-  }
-
-  private void addDefinitionToBatch(Sha1HashId defId, String name, String tenantId, String region, String id) {
+  private void addDefinitionToBatch(Sha1HashId defId, String name, String tenantId, String region) {
 
     if (definitionsIdCache.getIfPresent(defId) == null) {
 
@@ -395,17 +337,11 @@ public class VerticaMetricRepo extends VerticaRepo implements Repo<MetricEnvelop
 
       if (!definitionIdSet.contains(defId)) {
 
-        logger.debug("[{}]: adding definition to batch: defId: {}, name: {}, tenantId: {}, region: {}",
-                     id, defId.toHexString(), name, tenantId, region);
-
-        stagedDefinitionsBatch.add()
-            .bind("id", defId.getSha1Hash())
-            .bind("name", name)
-            .bind("tenant_id", tenantId)
-            .bind("region", region);
-
+        logger.debug("Adding definition to batch: defId: {}, name: {}, tenantId: {}, region: {}",
+                     defId.toHexString(), name, tenantId, region);
+        stagedDefinitionsBatch.add().bind("id", defId.getSha1Hash()).bind("name", name)
+            .bind("tenant_id", tenantId).bind("region", region);
         definitionIdSet.add(defId);
-
       }
 
     } else {
@@ -415,7 +351,7 @@ public class VerticaMetricRepo extends VerticaRepo implements Repo<MetricEnvelop
     }
   }
 
-  private void addDimensionsToBatch(Sha1HashId dimSetId, Map<String, String> dimMap, String id) {
+  private void addDimensionsToBatch(Sha1HashId dimSetId, Map<String, String> dimMap) {
 
     if (dimensionsIdCache.getIfPresent(dimSetId) == null) {
 
@@ -428,14 +364,10 @@ public class VerticaMetricRepo extends VerticaRepo implements Repo<MetricEnvelop
           String name = entry.getKey();
           String value = entry.getValue();
 
-          logger.debug(
-              "[{}]: adding dimension to batch: dimSetId: {}, name: {}, value: {}",
-              id, dimSetId.toHexString(), name, value);
+          logger.debug("Adding dimension to batch: dimSetId: {}, name: {}, value: {}", dimSetId.toHexString(), name, value);
 
-          stagedDimensionsBatch.add()
-              .bind("dimension_set_id", dimSetId.getSha1Hash())
-              .bind("name", name)
-              .bind("value", value);
+          stagedDimensionsBatch.add().bind("dimension_set_id", dimSetId.getSha1Hash())
+              .bind("name", name).bind("value", value);
         }
 
         dimensionIdSet.add(dimSetId);
@@ -449,7 +381,7 @@ public class VerticaMetricRepo extends VerticaRepo implements Repo<MetricEnvelop
   }
 
   private void addDefinitionDimensionToBatch(Sha1HashId defDimsId, Sha1HashId defId,
-                                            Sha1HashId dimId, String id) {
+                                            Sha1HashId dimId) {
 
     if (definitionDimensionsIdCache.getIfPresent(defDimsId) == null) {
 
@@ -457,11 +389,9 @@ public class VerticaMetricRepo extends VerticaRepo implements Repo<MetricEnvelop
 
       if (!definitionDimensionsIdSet.contains(defDimsId)) {
 
-        logger.debug("[{}]: adding definitionDimension to batch: defDimsId: {}, defId: {}, dimId: {}",
-                     id, defDimsId.toHexString(), defId, dimId);
-
-        stagedDefinitionDimensionsBatch.add()
-            .bind("id", defDimsId.getSha1Hash())
+        logger.debug("Adding definitionDimension to batch: defDimsId: {}, defId: {}, dimId: {}",
+                     defDimsId.toHexString(), defId, dimId);
+        stagedDefinitionDimensionsBatch.add().bind("id", defDimsId.getSha1Hash())
             .bind("definition_id", defId.getSha1Hash())
             .bind("dimension_set_id", dimId.getSha1Hash());
 
@@ -476,179 +406,100 @@ public class VerticaMetricRepo extends VerticaRepo implements Repo<MetricEnvelop
   }
 
   @Override
-  public int flush(String id) throws RepoException {
-
+  public int flush(String id) {
     try {
-
-      Stopwatch swOuter = Stopwatch.createStarted();
-
-      Timer.Context context = commitTimer.time();
-
-      executeBatches(id);
-
-      writeRowsFromTempStagingTablesToPermTables(id);
-
-      Stopwatch swInner = Stopwatch.createStarted();
-
+      long startTime = System.currentTimeMillis();
+      Timer.Context context = flushTimer.time();
+      executeBatches();
+      writeRowsFromTempStagingTablesToPermTables();
       handle.commit();
-      swInner.stop();
-
-      logger.debug("[{}]: committing transaction took: {}", id, swInner);
-
-      swInner.reset().start();
       handle.begin();
-      swInner.stop();
-
-      logger.debug("[{}]: beginning new transaction took: {}", id, swInner);
-
+      long endTime = System.currentTimeMillis();
       context.stop();
-
-      swOuter.stop();
-
-      logger.debug("[{}]: total time for writing measurements, definitions, and dimensions to vertica took {}",
-                   id, swOuter);
-
-      updateIdCaches(id);
-
-      int commitCnt = this.measurementCnt;
-
-      this.measurementCnt = 0;
-
-      return commitCnt;
-
+      logger.debug("Writing measurements, definitions, and dimensions to database took "
+          + (endTime - startTime) / 1000 + " seconds");
+      updateIdCaches();
     } catch (Exception e) {
-
-      logger.error("[{}]: failed to write measurements, definitions, and dimensions to vertica", id,
-                   e);
-
-      throw new RepoException("failed to commit batch to vertica", e);
-
+      logger.error("Failed to write measurements, definitions, or dimensions to database", e);
+      if (handle.isInTransaction()) {
+        handle.rollback();
+      }
+      clearTempCaches();
+      handle.begin();
     }
+
+    // Todo. implement cnt.
+    return 0;
   }
 
-  private void executeBatches(String id) {
-
-    Stopwatch sw = Stopwatch.createStarted();
+  private void executeBatches() {
 
     metricsBatch.execute();
-
     stagedDefinitionsBatch.execute();
-
     stagedDimensionsBatch.execute();
-
     stagedDefinitionDimensionsBatch.execute();
-
-    sw.stop();
-
-    logger.debug("[{}]: executing batches took {}: ", id, sw);
-
   }
 
-  private void updateIdCaches(String id) {
-
-    Stopwatch sw = Stopwatch.createStarted();
-
+  private void updateIdCaches() {
     for (Sha1HashId defId : definitionIdSet) {
-
       definitionsIdCache.put(defId, defId);
     }
 
     for (Sha1HashId dimId : dimensionIdSet) {
-
       dimensionsIdCache.put(dimId, dimId);
     }
 
     for (Sha1HashId defDimsId : definitionDimensionsIdSet) {
-
       definitionDimensionsIdCache.put(defDimsId, defDimsId);
     }
 
     clearTempCaches();
-
-    sw.stop();
-
-    logger.debug("[{}]: clearing temp caches took: {}", id, sw);
-
   }
 
-  private void writeRowsFromTempStagingTablesToPermTables(String id) {
-
-    Stopwatch sw = Stopwatch.createStarted();
-
+  private void writeRowsFromTempStagingTablesToPermTables() {
     handle.execute(definitionsTempStagingTableInsertStmt);
     handle.execute("truncate table " + definitionsTempStagingTableName);
-    sw.stop();
-
-    logger.debug("[{}]: flushing definitions temp staging table took: {}", id, sw);
-
-    sw.reset().start();
     handle.execute(dimensionsTempStagingTableInsertStmt);
     handle.execute("truncate table " + dimensionsTempStagingTableName);
-    sw.stop();
-
-    logger.debug("[{}]: flushing dimensions temp staging table took: {}", id, sw);
-
-    sw.reset().start();
     handle.execute(definitionDimensionsTempStagingTableInsertStmt);
     handle.execute("truncate table " + definitionDimensionsTempStagingTableName);
-    sw.stop();
-
-    logger.debug("[{}]: flushing definition dimensions temp staging table took: {}", id, sw);
   }
 
   private void clearTempCaches() {
-
     definitionIdSet.clear();
     dimensionIdSet.clear();
     definitionDimensionsIdSet.clear();
-
   }
 
-  private Map<String, String> prepDimensions(Map<String, String> dimMap, String id) {
+  private Map<String, String> prepDimensions(Map<String, String> dimMap) {
 
     Map<String, String> newDimMap = new TreeMap<>();
 
     if (dimMap != null) {
-
       for (String dimName : dimMap.keySet()) {
-
         if (dimName != null && !dimName.isEmpty()) {
-
           String dimValue = dimMap.get(dimName);
-
           if (dimValue != null && !dimValue.isEmpty()) {
-
-            newDimMap.put(trunc(dimName, MAX_COLUMN_LENGTH, id),
-                          trunc(dimValue, MAX_COLUMN_LENGTH, id));
-
+            newDimMap.put(trunc(dimName, MAX_COLUMN_LENGTH), trunc(dimValue, MAX_COLUMN_LENGTH));
+            dimensionCounter.inc();
           }
         }
       }
     }
-
     return newDimMap;
-
   }
 
-  private String trunc(String s, int l, String id) {
+  private String trunc(String s, int l) {
 
     if (s == null) {
-
       return "";
-
     } else if (s.length() <= l) {
-
       return s;
-
     } else {
-
       String r = s.substring(0, l);
-
-      logger.warn( "[{}]: input string exceeded max column length. truncating input string {} to {} chars",
-                   id, s, l);
-
-      logger.warn("[{}]: resulting string {}", id, r);
-
+      logger.warn("Input string exceeded max column length. Truncating input string {} to {} chars",
+                  s, l);
+      logger.warn("Resulting string {}", r);
       return r;
     }
   }
